@@ -6,7 +6,7 @@ use IO::All;
 use List::Util 'uniq';
 use namespace::autoclean;
 
-our $VERSION = '0.1.8'; # VERSION:
+our $VERSION = '0.1.11'; # VERSION:
 # ABSTRACT: used to submit a batch of task to Torque cluster
 
 
@@ -48,7 +48,8 @@ has name => (
 has parallel => (
   is  => 'rw',
   isa => 'Int',
-  default => sub { '1' }
+  lazy => 1,
+  default => sub { shift->count_tasks }
 );
 
 has _log => (
@@ -94,8 +95,8 @@ has stage => (
 
 sub execute {
   my $self = shift;
-  my $task_run_num = $self->parallel;
   my @tasks =  $self->all_tasks;
+  my $task_run_num = $self->parallel;
   my @stages = uniq (map { $_->priority } @tasks);
   my $content = "name\tcpu\tpriority\tsh_name\tjob_id\tstat\tcmd\n";
   $self->_log->lock->append($content)->unlock;
@@ -146,7 +147,7 @@ Bioinfo::PBS::Queue - used to submit a batch of task to Torque cluster
 
 =head1 VERSION
 
-version 0.1.8
+version 0.1.11
 
 =head1 SYNOPSIS
 
